pub struct ActivityHistoryGetRequest {
pub from: NaiveDateTime,
pub to: Option<NaiveDateTime>,
pub detailed: Option<bool>,
pub deal_id: Option<String>,
pub filter: Option<String>,
pub page_size: Option<u32>,
}Expand description
Returns the activity history by sending a GET request to the /history/activity endpoint.
Fields
from: NaiveDateTimeStart date.
to: Option<NaiveDateTime>End date (Default = current time. A date without time component refers to the end of that day.).
detailed: Option<bool>Indicates whether to retrieve additional details about the activity.
deal_id: Option<String>Deal ID.
filter: Option<String>FIQL filter (supported operators: ==|!=|,|;).
page_size: Option<u32>Page size (min: 10, max: 500).