pub struct ConfirmsGetRequest {
pub deal_reference: String,
}Expand description
GET Request to /confirms/{dealReference} endpoint to retrieve deal confirmations for the given deal reference. Please note, this should only be used if the deal confirmation isn’t received via the streaming API.
Fields
deal_reference: StringTrait Implementations
Sourceimpl Debug for ConfirmsGetRequest
impl Debug for ConfirmsGetRequest
Sourceimpl<'de> Deserialize<'de> for ConfirmsGetRequest
impl<'de> Deserialize<'de> for ConfirmsGetRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for ConfirmsGetRequest
impl Serialize for ConfirmsGetRequest